@@ -32,22 +32,32 @@ func initMathBig(pkg *gox.Package, conf *gox.Config, big *gox.PkgRef) {
 	conf.UntypedBigFloat = big.Ref("UntypedBigfloat").Type().(*types.Named)
 }
 
-func initBuiltin(pkg *gox.Package, builtin *types.Package, fmt, ng, buil *gox.PkgRef) {
+func initBuiltinFns(builtin *types.Package, scope *types.Scope, pkg *gox.PkgRef, fns []string) {
+	for _, fn := range fns {
+		fnTitle := string(fn[0]-'a'+'A') + fn[1:]
+		scope.Insert(gox.NewOverloadFunc(token.NoPos, builtin, fn, pkg.Ref(fnTitle)))
+	}
+}
+
+func initBuiltin(pkg *gox.Package, builtin *types.Package, os, fmt, ng, iox, buil *gox.PkgRef) {
 	scope := builtin.Scope()
 	typs := []string{"bigint", "bigrat", "bigfloat"}
 	for _, typ := range typs {
 		name := string(typ[0]-('a'-'A')) + typ[1:]
 		scope.Insert(types.NewTypeName(token.NoPos, builtin, typ, ng.Ref(name).Type()))
 	}
-	fns := []string{
+	initBuiltinFns(builtin, scope, fmt, []string{
 		"print", "println", "printf", "errorf",
 		"fprint", "fprintln", "fprintf",
 		"sprint", "sprintln", "sprintf",
-	}
-	for _, fn := range fns {
-		fnTitle := string(fn[0]-'a'+'A') + fn[1:]
-		scope.Insert(gox.NewOverloadFunc(token.NoPos, builtin, fn, fmt.Ref(fnTitle)))
-	}
+	})
+	initBuiltinFns(builtin, scope, os, []string{
+		"open", "create",
+	})
+	initBuiltinFns(builtin, scope, iox, []string{
+		"lines",
+	})
+	scope.Insert(gox.NewOverloadFunc(token.NoPos, builtin, "blines", iox.Ref("BLines")))
 	scope.Insert(gox.NewOverloadFunc(token.NoPos, builtin, "newRange", buil.Ref("NewRange__0")))
 	scope.Insert(types.NewTypeName(token.NoPos, builtin, "uint128", ng.Ref("Uint128").Type()))
 	scope.Insert(types.NewTypeName(token.NoPos, builtin, "int128", ng.Ref("Int128").Type()))
@@ -57,12 +67,14 @@ func initBuiltin(pkg *gox.Package, builtin *types.Package, fmt, ng, buil *gox.Pk
 func newBuiltinDefault(pkg *gox.Package, conf *gox.Config) *types.Package {
 	builtin := types.NewPackage("", "")
 	fmt := pkg.Import("fmt")
+	os := pkg.Import("os")
 	buil := pkg.Import("github.com/goplus/gop/builtin")
 	ng := pkg.Import("github.com/goplus/gop/builtin/ng")
+	iox := pkg.Import("github.com/goplus/gop/builtin/iox")
 	pkg.Import("strconv")
 	pkg.Import("strings")
 	initMathBig(pkg, conf, ng)
-	initBuiltin(pkg, builtin, fmt, ng, buil)
+	initBuiltin(pkg, builtin, os, fmt, ng, iox, buil)
 	gox.InitBuiltin(pkg, builtin, conf)
 	return builtin
 }
