@@ -99,8 +99,11 @@ type Config struct {
 	// NoAutoGenMain = true means not to auto generate main func is no entry.
 	NoAutoGenMain bool
 
-	// NoSkipConstant = true means disable optimization of skip constants
+	// NoSkipConstant = true means to disable optimization of skipping constants.
 	NoSkipConstant bool
+
+	// Outline = true means to skip compiling function bodies.
+	Outline bool
 }
 
 type nodeInterp struct {
@@ -153,9 +156,9 @@ type baseLoader struct {
 	start token.Pos
 }
 
-func initLoader(ctx *pkgCtx, syms map[string]loader, start token.Pos, name string, fn func(), genCode bool) {
+func initLoader(ctx *pkgCtx, syms map[string]loader, start token.Pos, name string, fn func(), genBody bool) {
 	if name == "_" {
-		if genCode {
+		if genBody {
 			ctx.inits = append(ctx.inits, fn)
 		}
 		return
@@ -244,14 +247,15 @@ func doInitMethods(ld *typeLoader) {
 type pkgCtx struct {
 	*nodeInterp
 	*gmxSettings
-	cpkgs    *cpackages.Importer
-	syms     map[string]loader
+	cpkgs *cpackages.Importer
+	syms  map[string]loader
+	inits []func()
+	tylds []*typeLoader
+	errs  errors.List
+
 	generics map[string]bool // generic type record
-	inits    []func()
-	tylds    []*typeLoader
-	idents   []*ast.Ident // toType ident recored
-	errs     errors.List
-	inInst   int // toType in generic instance
+	idents   []*ast.Ident    // toType ident recored
+	inInst   int             // toType in generic instance
 }
 
 type blockCtx struct {
@@ -424,13 +428,15 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 		preloadGopFile(p, ctx, fpath, f, conf)
 	}
 
+	gofiles := make([]*ast.File, 0, len(pkg.GoFiles))
 	for fpath, gof := range pkg.GoFiles {
 		f := fromgo.ASTFile(gof, 0)
+		gofiles = append(gofiles, f)
 		ctx := &blockCtx{
 			pkg: p, pkgCtx: ctx, cb: p.CB(), fset: p.Fset, targetDir: targetDir,
 			imports: make(map[string]*gox.PkgRef),
 		}
-		preloadFile(p, ctx, fpath, f, false)
+		preloadFile(p, ctx, fpath, f, false, false)
 	}
 
 	// sort files
@@ -438,7 +444,7 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 		*ast.File
 		path string
 	}
-	var sfiles []*File
+	sfiles := make([]*File, 0, len(files))
 	for fpath, f := range files {
 		sfiles = append(sfiles, &File{f, fpath})
 	}
@@ -458,6 +464,11 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 			loadFile(ctx, f.File)
 		}
 	}
+	if conf.Outline {
+		for _, f := range gofiles {
+			loadFile(ctx, f)
+		}
+	}
 	for _, ld := range ctx.tylds {
 		ld.load()
 	}
@@ -489,13 +500,13 @@ func hasMethod(o types.Object, name string) bool {
 	return false
 }
 
-func getEntrypoint(f *ast.File, isMod bool) string {
+func getEntrypoint(f *ast.File) string {
 	switch {
 	case f.IsProj:
 		return "MainEntry"
 	case f.IsClass:
 		return "Main"
-	case isMod:
+	case f.Name.Name != "main":
 		return "init"
 	default:
 		return "main"
@@ -533,8 +544,8 @@ func loadFile(ctx *pkgCtx, f *ast.File) {
 	}
 }
 
-func getGoFile(file string, genCode bool) string {
-	if genCode {
+func genGoFile(file string, gopFile bool) string {
+	if gopFile {
 		if strings.HasSuffix(file, "_test.gop") {
 			return testingGoFile
 		}
@@ -639,8 +650,8 @@ func preloadGopFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, con
 		}}}
 	}
 	// check class project no MainEntry and auto added
-	if f.IsProj && !conf.NoAutoGenMain && !f.NoEntrypoint && f.Name.Name == "main" {
-		entry := getEntrypoint(f, false)
+	if f.IsProj && !conf.NoAutoGenMain && !f.NoEntrypoint() && f.Name.Name == "main" {
+		entry := getEntrypoint(f)
 		var hasEntry bool
 		for _, decl := range f.Decls {
 			switch d := decl.(type) {
@@ -658,7 +669,10 @@ func preloadGopFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, con
 			})
 		}
 	}
-	preloadFile(p, ctx, file, f, true)
+	if d := f.ShadowEntry; d != nil {
+		d.Name.Name = getEntrypoint(f)
+	}
+	preloadFile(p, ctx, file, f, true, !conf.Outline)
 }
 
 func parseTypeEmbedName(typ ast.Expr) *ast.Ident {
@@ -675,39 +689,29 @@ retry:
 	return nil
 }
 
-func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, genCode bool) {
+func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, gopFile, genFnBody bool) {
 	parent := ctx.pkgCtx
 	syms := parent.syms
-	goFile := getGoFile(file, genCode)
+	goFile := genGoFile(file, gopFile)
 	old, _ := p.SetCurFile(goFile, true)
 	defer p.RestoreCurFile(old)
 	for _, decl := range f.Decls {
 		switch d := decl.(type) {
 		case *ast.FuncDecl:
-			if f.NoEntrypoint && d.Name.Name == "main" {
-				d.Name.Name = getEntrypoint(f, f.Name.Name != "main")
-			}
 			if ctx.classRecv != nil { // in class file (.spx/.gmx)
 				if d.Recv == nil {
 					d.Recv = ctx.classRecv
 				}
 			}
 			if d.Recv == nil {
-				var name = d.Name
-				var fn func()
-				if genCode {
-					fn = func() {
-						old, _ := p.SetCurFile(goFile, true)
-						defer p.RestoreCurFile(old)
-						loadFunc(ctx, nil, d)
-					}
-				} else {
-					fn = func() {
-						declFunc(ctx, nil, d)
-					}
+				name := d.Name
+				fn := func() {
+					old, _ := p.SetCurFile(goFile, true)
+					defer p.RestoreCurFile(old)
+					loadFunc(ctx, nil, d, genFnBody)
 				}
 				if name.Name == "init" {
-					if genCode {
+					if genFnBody {
 						if debugLoad {
 							log.Println("==> Preload func init")
 						}
@@ -717,29 +721,20 @@ func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, genCod
 					if debugLoad {
 						log.Println("==> Preload func", name.Name)
 					}
-					initLoader(parent, syms, name.Pos(), name.Name, fn, genCode)
+					initLoader(parent, syms, name.Pos(), name.Name, fn, genFnBody)
 				}
 			} else {
 				if name, ok := getRecvTypeName(parent, d.Recv, true); ok {
 					if debugLoad {
 						log.Printf("==> Preload method %s.%s\n", name, d.Name.Name)
 					}
-					var ld = getTypeLoader(parent, syms, token.NoPos, name)
-					var fn func()
-					if genCode {
-						fn = func() {
-							old, _ := p.SetCurFile(goFile, true)
-							defer p.RestoreCurFile(old)
-							doInitType(ld)
-							recv := toRecv(ctx, d.Recv)
-							loadFunc(ctx, recv, d)
-						}
-					} else {
-						fn = func() {
-							doInitType(ld)
-							recv := toRecv(ctx, d.Recv)
-							declFunc(ctx, recv, d)
-						}
+					ld := getTypeLoader(parent, syms, token.NoPos, name)
+					fn := func() {
+						old, _ := p.SetCurFile(goFile, true)
+						defer p.RestoreCurFile(old)
+						doInitType(ld)
+						recv := toRecv(ctx, d.Recv)
+						loadFunc(ctx, recv, d, genFnBody)
 					}
 					ld.methods = append(ld.methods, fn)
 				}
@@ -758,7 +753,8 @@ func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, genCod
 						log.Println("==> Preload type", name)
 					}
 					ld := getTypeLoader(parent, syms, t.Name.Pos(), name)
-					if genCode {
+					defs := ctx.pkg.NewTypeDefs()
+					if gopFile {
 						ld.typ = func() {
 							old, _ := p.SetCurFile(goFile, true)
 							defer p.RestoreCurFile(old)
@@ -772,11 +768,11 @@ func preloadFile(p *gox.Package, ctx *blockCtx, file string, f *ast.File, genCod
 							if debugLoad {
 								log.Println("==> Load > NewType", name)
 							}
-							decl := ctx.pkg.NewType(name)
+							decl := defs.NewType(name)
 							if t.Doc != nil {
-								decl.SetComments(t.Doc)
+								defs.SetComments(t.Doc)
 							} else if d.Doc != nil {
-								decl.SetComments(d.Doc)
+								defs.SetComments(d.Doc)
 							}
 							ld.typInit = func() { // decycle
 								if debugLoad {
@@ -867,40 +863,7 @@ func aliasType(pkg *types.Package, pos token.Pos, name string, typ types.Type) {
 	pkg.Scope().Insert(o)
 }
 
-func declFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl) {
-	name := d.Name.Name
-	if debugLoad {
-		if recv == nil {
-			log.Println("==> Load func", name)
-		} else {
-			log.Printf("==> Load method %v.%s\n", recv.Type(), name)
-		}
-	}
-	if name == "_" {
-		return
-	}
-	pkg := ctx.pkg.Types
-	sig := toFuncType(ctx, d.Type, recv, d)
-	fn := types.NewFunc(d.Pos(), pkg, name, sig)
-	if recv != nil {
-		typ := recv.Type()
-		switch t := typ.(type) {
-		case *types.Named:
-			t.AddMethod(fn)
-			return
-		case *types.Pointer:
-			if tt, ok := t.Elem().(*types.Named); ok {
-				tt.AddMethod(fn)
-				return
-			}
-		}
-		log.Panicf("invalid receiver type %v (%v is not a defined type)\n", typ, typ)
-	} else {
-		pkg.Scope().Insert(fn)
-	}
-}
-
-func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl) {
+func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl, genBody bool) {
 	name := d.Name.Name
 	if debugLoad {
 		if recv == nil {
@@ -936,13 +899,15 @@ func loadFunc(ctx *blockCtx, recv *types.Var, d *ast.FuncDecl) {
 	if d.Doc != nil {
 		fn.SetComments(d.Doc)
 	}
-	if body := d.Body; body != nil {
-		if recv != nil {
-			ctx.inits = append(ctx.inits, func() { // interface issue: #795
-				loadFuncBody(ctx, fn, body)
-			})
-		} else {
-			loadFuncBody(ctx, fn, body)
+	if genBody {
+		if body := d.Body; body != nil {
+			if recv != nil {
+				ctx.inits = append(ctx.inits, func() { // interface issue: #795
+					loadFuncBody(ctx, fn, body, d)
+				})
+			} else {
+				loadFuncBody(ctx, fn, body, d)
+			}
 		}
 	}
 }
@@ -997,10 +962,10 @@ var unaryGopNames = map[string]string{
 	"<-": "Gop_Recv",
 }
 
-func loadFuncBody(ctx *blockCtx, fn *gox.Func, body *ast.BlockStmt) {
+func loadFuncBody(ctx *blockCtx, fn *gox.Func, body *ast.BlockStmt, src ast.Node) {
 	cb := fn.BodyStart(ctx.pkg)
 	compileStmts(ctx, body.List)
-	cb.End()
+	cb.End(src)
 }
 
 func simplifyGopPackage(pkgPath string) string {
@@ -1047,14 +1012,14 @@ func loadImport(ctx *blockCtx, spec *ast.ImportSpec) {
 	ctx.imports[name] = pkg
 }
 
-func loadConstSpecs(ctx *blockCtx, cdecl *gox.ConstDecl, specs []ast.Spec) {
+func loadConstSpecs(ctx *blockCtx, cdecl *gox.ConstDefs, specs []ast.Spec) {
 	for iotav, spec := range specs {
 		vSpec := spec.(*ast.ValueSpec)
 		loadConsts(ctx, cdecl, vSpec, iotav)
 	}
 }
 
-func loadConsts(ctx *blockCtx, cdecl *gox.ConstDecl, v *ast.ValueSpec, iotav int) {
+func loadConsts(ctx *blockCtx, cdecl *gox.ConstDefs, v *ast.ValueSpec, iotav int) {
 	names := makeNames(v.Names)
 	if v.Values == nil {
 		if debugLoad {
