@@ -830,6 +830,11 @@ scanAgain:
 			case token.IDENT, token.BREAK, token.CONTINUE, token.FALLTHROUGH, token.RETURN:
 				insertSemi = true
 			}
+		} else if lit == "C" && s.ch == '"' { // C"..."
+			s.next()
+			insertSemi = true
+			tok = token.CSTRING
+			lit = s.scanString()
 		} else {
 			insertSemi = true
 			tok = token.IDENT
